aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Robertz <dream-master@gmx.net>2023-01-28 15:28:04 +0100
committerMartin Robertz <dream-master@gmx.net>2023-01-28 15:28:04 +0100
commitbb4aad4bc389cbe5d21174d2571880f607d4ee0f (patch)
tree426f2f2f2c06d1d734ee36bb506e6f289cec81cc
parent869ac3db5c1598c7537242630c22eedd8a5b94f5 (diff)
downloadGT5-Unofficial-bb4aad4bc389cbe5d21174d2571880f607d4ee0f.tar.gz
GT5-Unofficial-bb4aad4bc389cbe5d21174d2571880f607d4ee0f.tar.bz2
GT5-Unofficial-bb4aad4bc389cbe5d21174d2571880f607d4ee0f.zip
Bs
-rw-r--r--build.gradle49
1 files changed, 36 insertions, 13 deletions
diff --git a/build.gradle b/build.gradle
index 89350b8a35..ca1b22cc52 100644
--- a/build.gradle
+++ b/build.gradle
@@ -1,4 +1,4 @@
-//version: 1669411416
+//version: 1674845916
/*
DO NOT CHANGE THIS FILE!
Also, you may replace this file at any time if there is an update available.
@@ -31,7 +31,7 @@ buildscript {
url 'https://maven.minecraftforge.net'
}
maven {
// GTNH ForgeGradle Fork
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"
}
@@ -45,7 +45,9 @@ buildscript {
}
}
dependencies {
- classpath 'net.minecraftforge.gradle:ForgeGradle:1.2.11'
+ //Overwrite the current ASM version to fix shading newer than java 8 applicatations.
+ classpath 'org.ow2.asm:asm-debug-all-custom:5.0.3'
+ classpath 'net.minecraftforge.gradle:ForgeGradle:1.2.13'
}
}
plugins {
@@ -142,6 +144,7 @@ propertyDefaultIfUnset("modrinthProjectId", "")
propertyDefaultIfUnset("modrinthRelations", "")
propertyDefaultIfUnset("curseForgeProjectId", "")
propertyDefaultIfUnset("curseForgeRelations", "")
+propertyDefaultIfUnset("minimizeShadowedDependencies", true)
String javaSourceDir = "src/main/java/"
String scalaSourceDir = "src/main/scala/"
@@ -278,7 +281,9 @@ minecraft {
runDir = 'run'
if (replaceGradleTokenInFile) {
- replaceIn replaceGradleTokenInFile
+ for (f in replaceGradleTokenInFile.split(',')) {
+ replaceIn f
+ }
if (gradleTokenModId) {
replace gradleTokenModId, modId
}
@@ -315,9 +320,13 @@ if (file('addon.gradle').exists()) {
apply from: 'repositories.gradle'
configurations {
- implementation.extendsFrom(shadowImplementation) // TODO: remove after all uses are refactored
- implementation.extendsFrom(shadowCompile)
- implementation.extendsFrom(shadeCompile)
+ // TODO: remove Compile after all uses are refactored to Implementation
+ for (config in [shadowImplementation, shadowCompile, shadeCompile]) {
+ compileClasspath.extendsFrom(config)
+ runtimeClasspath.extendsFrom(config)
+ testCompileClasspath.extendsFrom(config)
+ testRuntimeClasspath.extendsFrom(config)
+ }
}
repositories {
@@ -330,6 +339,12 @@ repositories {
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"
}
+ if (usesMixinDebug.toBoolean()) {
+ maven {
+ name = "Fabric Maven"
+ url = "https://maven.fabricmc.net/"
+ }
+ }
}
}
@@ -338,10 +353,14 @@ dependencies {
annotationProcessor('org.ow2.asm:asm-debug-all:5.0.3')
annotationProcessor('com.google.guava:guava:24.1.1-jre')
annotationProcessor('com.google.code.gson:gson:2.8.6')
- annotationProcessor('com.gtnewhorizon:gtnhmixins:2.1.1:processor')
+ annotationProcessor('com.gtnewhorizon:gtnhmixins:2.1.3:processor')
+ if (usesMixinDebug.toBoolean()) {
+ runtimeClasspath('org.jetbrains:intellij-fernflower:1.2.1.16')
+ testRuntimeClasspath('org.jetbrains:intellij-fernflower:1.2.1.16')
+ }
}
if (usesMixins.toBoolean() || forceEnableMixins.toBoolean()) {
- compile('com.gtnewhorizon:gtnhmixins:2.1.1')
+ compile('com.gtnewhorizon:gtnhmixins:2.1.3')
}
}
@@ -393,7 +412,9 @@ shadowJar {
attributes(getManifestAttributes())
}
- minimize() // This will only allow shading for actually used classes
+ if (minimizeShadowedDependencies.toBoolean()) {
+ minimize() // This will only allow shading for actually used classes
+ }
configurations = [
project.configurations.shadowImplementation,
project.configurations.shadowCompile
@@ -536,7 +557,9 @@ task shadowDevJar(type: ShadowJar) {
attributes(getManifestAttributes())
}
- minimize() // This will only allow shading for actually used classes
+ if (minimizeShadowedDependencies.toBoolean()) {
+ minimize() // This will only allow shading for actually used classes
+ }
configurations = [
project.configurations.shadowImplementation,
project.configurations.shadowCompile
@@ -694,7 +717,7 @@ if (modrinthProjectId.size() != 0 && System.getenv("MODRINTH_TOKEN") != null) {
}
}
if (usesMixins.toBoolean()) {
- addModrinthDep("required", "version", "gtnhmixins")
+ addModrinthDep("required", "project", "gtnhmixins")
}
tasks.modrinth.dependsOn(build)
tasks.publish.dependsOn(tasks.modrinth)
@@ -780,7 +803,7 @@ task updateBuildScript {
}
}
-if (!project.getGradle().startParameter.isOffline() && isNewBuildScriptVersionAvailable(projectDir.toString())) {
+if (!project.getGradle().startParameter.isOffline() && !Boolean.getBoolean('DISABLE_BUILDSCRIPT_UPDATE_CHECK') && isNewBuildScriptVersionAvailable(projectDir.toString())) {
if (autoUpdateBuildScript.toBoolean()) {
performBuildScriptUpdate(projectDir.toString())
} else {
@@ -31,7 +31,7 @@ buildscript {
}
maven {
- // GTNH ForgeGradle Fork
+ // GTNH ForgeGradle and ASM Fork
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"